pub fn dump_table(
conn: &mut dyn Connection,
table: &str,
backend: Backend,
opts: &DumpOptions,
) -> Result<String, SqlError>Expand description
Dump an entire table by streaming a single native cursor.
pub fn dump_table(
conn: &mut dyn Connection,
table: &str,
backend: Backend,
opts: &DumpOptions,
) -> Result<String, SqlError>Dump an entire table by streaming a single native cursor.