Module explain

Module explain 

Enums

ExplainOutput
Tag indicating the expected output format of an EXPLAIN plan.

Functions

explain_sql
Return the EXPLAIN-wrapped SQL, the expected output format, and whether the wrapped SQL contains multiple statements (which requires execute_multi).
is_modifying
Detect whether a SQL statement is modifying (DML/DDL).